#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import json
from pathlib import Path
from typing import Iterable, TypedDict, List, Dict, Any

from .bakery_api.v1 import (
   OS,
   Plugin,
   PluginConfig,
   SystemBinary,
   register,
   FileGenerator,
   quote_shell_string,
)

def get_win_smart_plugin_files(conf: Dict[str, Any]) -> FileGenerator:
   yield Plugin(
      base_os=OS.WINDOWS,
      source=Path('win_smart.ps1'),
      target=Path('win_smart.ps1'),
   )

   exe_dst = "C:\\ProgramData\\checkmk\\agent\\bin\\smartctl.exe"
   if conf[0] == "no_smartctlexe":
      exe_dst = conf[1][1]

   yield PluginConfig(base_os=OS.WINDOWS,
                     lines=_get_lsmartctl_path_line(exe_dst),
                     target=Path('smartctl_path.json'),
                     include_header=False)

   if conf[0] == "smartctlexe":
      yield SystemBinary(
         base_os=OS.WINDOWS,
         source=Path('smartctl.exe'),
         target=Path('smartctl.exe'),
      )

def _get_lsmartctl_path_line(smartctlexe: str) -> List[str]:
   config = json.dumps({'smartctlexe': smartctlexe})
   return config.split('\n')

register.bakery_plugin(
   name="win_smart",
   files_function=get_win_smart_plugin_files,
)
